m4-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Changes to m4/modules/perl.c,v


From: Eric Blake
Subject: Changes to m4/modules/perl.c,v
Date: Fri, 25 Aug 2006 22:06:45 +0000

CVSROOT:        /sources/m4
Module name:    m4
Changes by:     Eric Blake <ericb>      06/08/25 22:06:42

Index: modules/perl.c
===================================================================
RCS file: /sources/m4/m4/modules/perl.c,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -b -r1.14 -r1.15
--- modules/perl.c      1 May 2005 11:10:05 -0000       1.14
+++ modules/perl.c      25 Aug 2006 22:06:42 -0000      1.15
@@ -1,5 +1,5 @@
 /* GNU m4 -- A simple macro processor
-   Copyright (C) 1999, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2006 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,24 +31,28 @@
 #define m4_builtin_table       perl_LTX_m4_builtin_table
 #define m4_macro_table         perl_LTX_m4_macro_table
 
 /*             function        macros  blind minargs maxargs */
 #define builtin_functions                                      \
-       BUILTIN (perleval,      false,  false,  0,      -1  )   \
+  BUILTIN (perleval,   false,  false,  false,  0,      -1  )   \
 
 
-#define BUILTIN(handler, macros,  blind, min, max)  M4BUILTIN(handler)
+#define BUILTIN(handler, macros, blind, side, min, max)  M4BUILTIN(handler)
   builtin_functions
 #undef BUILTIN
 
 m4_builtin m4_builtin_table[] =
 {
-#define BUILTIN(handler, macros, blind, min, max)              \
-       { STR(handler), CONC(builtin_, handler), macros, blind, min, max },
+#define BUILTIN(handler, macros, blind, side, min, max)        \
+  { CONC(builtin_, handler), STR(handler),             \
+    ((macros ? M4_BUILTIN_GROKS_MACRO : 0)             \
+     | (blind ? M4_BUILTIN_BLIND : 0)                  \
+     | (side ? M4_BUILTIN_SIDE_EFFECT : 0)),           \
+    min, max },
 
   builtin_functions
 #undef BUILTIN
 
-  { 0, 0, false, false, 0, 0 },
+  { NULL, NULL, 0, 0, 0 },
 };
 
 /* A table for mapping m4 symbol names to simple expansion text. */
@@ -56,7 +60,7 @@
 {
   /* name                      text */
   { "__perleval__",            "" },
-  { 0, 0 },
+  { NULL, NULL },
 };
 
 
@@ -31,24 +31,28 @@
 #define m4_macro_table         perl_LTX_m4_macro_table
 
-/*             function        macros  blind minargs maxargs */
+/*        function     macros  blind   side    minargs maxargs */
 #define builtin_functions                                      \




reply via email to

[Prev in Thread] Current Thread [Next in Thread]